use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Adam
Alexandr
Bengen
Berry
Bowers
Bunce
Ciornii
Craig
David
Etheridge
Flavio
Golden
Graham
Hilko
Ingy
James
Karen
Keenan
Kennedy
Knop
Kogman
Mengué
Müller
Neil
Net
Olivier
Poletti
Rezic
Slaven
Steffen
Tim
Tiny
YAML
Yuval
adamk
bengen
chorny
craigberry
dagolden
dolmen
döt
ether
flavio
haarg
ingy
irc
jkeenan
lib
neil
nothingmuch
slaven
smueller
xdg
יובל
קוג
